package com.ruoyi.bst.article.service;

import java.util.List;
import com.ruoyi.bst.article.domain.Article;
import com.ruoyi.bst.article.domain.ArticleVO;
import com.ruoyi.bst.article.domain.ArticleQuery;
import com.ruoyi.bst.device.domain.DeviceVO;

/**
 * 文章Service接口
 *
 * @author ruoyi
 * @date 2025-03-27
 */
public interface ArticleService
{
    /**
     * 查询文章
     *
     * @param id 文章主键
     * @return 文章
     */
    public ArticleVO selectArticleById(Long id);

    /**
     * 查询文章列表
     *
     * @param article 文章
     * @return 文章集合
     */
    public List<ArticleVO> selectArticleList(ArticleQuery article);

    /**
     * 新增文章
     *
     * @param article 文章
     * @return 结果
     */
    public int insertArticle(Article article);

    /**
     * 修改文章
     *
     * @param article 文章
     * @return 结果
     */
    public int updateArticle(Article article);

    /**
     * 批量删除文章
     *
     * @param ids 需要删除的文章主键集合
     * @return 结果
     */
    public int deleteArticleByIds(Long[] ids);

    /**
     * 删除文章信息
     *
     * @param id 文章主键
     * @return 结果
     */
    public int deleteArticleById(Long id);


    List<ArticleVO> selectArticleByCategoryId(Long categoryId);

    /**
     * 查询设备
     *
     * @param code 设备主键
     * @return 设备
     */
    public ArticleVO selectArticleByCode(String code, boolean scope);

    default ArticleVO selectArticleByCode(String code) {
        return this.selectArticleByCode(code, false);
    }

}
